@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: syb
-version: 0.3.3
-id: syb-0.3.3-dd575fa8180bf87dbbe1727117c3b35c
+version: 0.3.7
+id: syb-0.3.7-60af41a2377e93620710d393692aff24
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: generics@haskell.org
 stability: provisional
 homepage: http://www.cs.uu.nl/wiki/GenericProgramming/SYB
 package-url:
+synopsis: Scrap Your Boilerplate
 description: This package contains the generics system described in the
              /Scrap Your Boilerplate/ papers (see
              <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
@@ -16,7 +17,7 @@ description: This package contains the generics system described in the
              of constructor applications, instances of this class for primitive
              types, and a variety of traversals.
 category: Generics
-author: Ralf Lammel, Simon Peyton Jones
+author: Ralf Lammel, Simon Peyton Jones, Jose Pedro Magalhaes
 pkgpath: devel/hs-syb
 exposed: True
 exposed-modules: Data.Generics Data.Generics.Basics
@@ -26,19 +27,20 @@ exposed-modules: Data.Generics Data.Generics.Basics
                  Generics.SYB.Aliases Generics.SYB.Schemes Generics.SYB.Text
                  Generics.SYB.Twins Generics.SYB.Builders
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/syb-0.3.3
-library-dirs: /usr/local/lib/ghc/syb-0.3.3
-hs-libraries: HSsyb-0.3.3
+trusted: False
+import-dirs: /usr/local/lib/ghc/syb-0.3.7
+library-dirs: /usr/local/lib/ghc/syb-0.3.7
+hs-libraries: HSsyb-0.3.7
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-syb-0.3.3/html/syb.haddock
-haddock-html: /usr/local/share/doc/hs-syb-0.3.3/html
+haddock-interfaces: /usr/local/share/doc/hs-syb-0.3.7/html/syb.haddock
+haddock-html: /usr/local/share/doc/hs-syb-0.3.7/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
